#!/usr/local/bin/dumb-init /bin/bash
set -x
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

HOSTNAME=`hostname -s`

# Be receptive to core dumps
ulimit -c unlimited

# Set number of file descriptors to 65K
ulimit -n 65536

if [ $# -lt 1 ];
then
    echo "USAGE: $0 [-daemon] server.properties [--override property=value]*"
    exit 1
fi
base_dir=$(dirname $0)

if [ "x$KAFKA_LOG4J_OPTS" = "x" ]; then
    export KAFKA_LOG4J_OPTS="-Dlog4j.configuration=file:$base_dir/../config/log4j.properties"
fi

if [ "x$KAFKA_HEAP_OPTS" = "x" ]; then
    export KAFKA_HEAP_OPTS="-Xmx1G -Xms1G"
fi

EXTRA_ARGS=${EXTRA_ARGS-'-name kafkaServer -loggc'}

COMMAND=$1
case $COMMAND in
  -daemon)
    EXTRA_ARGS="-daemon "$EXTRA_ARGS
    shift
    ;;
  *)
    ;;
esac

if [ "x$JMX_RMI_SERVER_HOSTNAME" = "x" ]; then
    echo "Environment variable JMX_RMI_SERVER_HOSTNAME is not set, exiting"
    exit 1
fi

echo $HOSTNAME
echo $JMX_RMI_SERVER_HOSTNAME
#export JMX_PORT=9999
export KAFKA_JMX_OPTS="-Dcom.sun.management.jmxremote \
-Dcom.sun.management.jmxremote.local.only=true"
if [ "${ENABLE_JMX_REMOTE}" != '' ]
then
export KAFKA_JMX_OPTS="-Dcom.sun.management.jmxremote \
-Dcom.sun.management.jmxremote.authenticate=false \
-Dcom.sun.management.jmxremote.ssl=false \
-Dcom.sun.management.jmxremote.local.only=false \
-Dcom.sun.management.jmxremote.port=9010 \
-Dcom.sun.management.jmxremote.rmi.port=9010 \
-Djava.rmi.server.hostname=0.0.0.0"
fi


#Creating truststore and keystores
if [ -d $SSL_MOUNT_PATH ]; then
   rm -rf $SSL_MOUNT_PATH
fi
mkdir -p $SSL_MOUNT_PATH
if [ -d  "/opt/kafka/ssl-certs" ]
then
cat /opt/kafka/ssl-certs/root*.pem > $SSL_MOUNT_PATH/root-bundle.pem
OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in /opt/kafka/ssl-certs/chain.pem -inkey /opt/kafka/ssl-certs/key.pem \
-out $SSL_MOUNT_PATH/localhost.p12 -name localhost -CAfile $SSL_MOUNT_PATH/root-bundle.pem \
-passout pass:$SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

keytool -importkeystore -deststorepass $SSL_KEY_PASSWORD -destkeypass \
$SSL_KEY_PASSWORD -destkeystore $SSL_MOUNT_PATH/$SSL_KEYSTORE_LOCATION -srckeystore $SSL_MOUNT_PATH/localhost.p12 \
-srcstoretype PKCS12 -srcstorepass $SSL_KEY_PASSWORD -alias localhost

COUNTER=0
for filename in `ls /opt/kafka/ssl-certs/root*.pem`; do
echo "Importing root cert $filename" 
keytool -noprompt -keystore $SSL_MOUNT_PATH/$SSL_TRUSTSTORE_LOCATION -alias diploma-$COUNTER \
-import -file $filename -storepass $SSL_KEY_PASSWORD -trustcacerts
COUNTER=$((COUNTER+1))
done
fi

exec $base_dir/kafka-run-class.sh $EXTRA_ARGS kafka.Kafka "$@"

if [ "$ENVIRONMENT" = "dev"  ] || [ "$ENVIRONMENT" = "preflight"  ]; then
    exec /opt/kafka/bin/create-topics.sh /opt/kafka/topics-preflight-dev.txt
fi
